@@ -1,14 +1,15 @@
 # -*- coding: utf-8 -*-
 __author__ = "Paul Schifferer <dm@sweetrpg.com>"
-"""Root.
+"""
+Root.
 """
 
 __title__ = "SweetRPG Model Core"
 __description__ = "Base classes and utilities for model objects"
 __url__ = "https://github.com/sweetrpg/model-core"
-__version__ = "0.0.113"
-__build__ = 0x00005e
+__version__ = "0.0.124"
+__build__ = 0x00005F
 __author_email__ = "dm@sweetrpg.com"
 __license__ = "MIT"
 __copyright__ = "Copyright 2023 SweetRPG"
-__cake__ = u"\u2728 \U0001f370 \u2728"
+__cake__ = "\u2728 \U0001f370 \u2728"
